package
Version:
v0.0.0-...-54f60d9
Opens a new window with list of versions in this module.
Published: Mar 7, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Like struct {
ID int64 `gorm:"primaryKey"`
UserID int64
BookID int64
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.